﻿using UnityEngine;
using System.Collections;
using System.Collections.Generic; 
using System.Runtime.Serialization.Formatters.Binary; 
using System.IO;
using System;
using GooglePlayGames;
using UnityEngine.SocialPlatforms;


public class ComprobarFicheros : MonoBehaviour {
	//Esta clase se ejecuta al principio del juego para comprobar si los archivos esenciales existen. 
	//Si los archivos no existen intenta copiarlos desde las librerias internas del juego.
	//En caso de que no pudiera copiarlas se crearia una excepcion, se muestra un mensaje y se sale del juego.

	// Los ficheros esenciales son:
	// Goals --> Contiene la informacion de la mision que hay que cumplir en cada nivel
	// Nivel --> Contiene la informacion de los objetos a instanciar para construir cada nivel
	// Setting --> Contine informacion del volumen de la musica y los efectos especiales
	// Record --> Contiene informacion del record personal en ese dispositivo. Este fichero en caso de no 
	// encontrarse se genera con los campos iniciados.
	// Status --> Contine la informacion de la puntuacion y nivel por donde va el jugardor.
	public string fullZipPathName = "";
	public string ficheroGoals="Goals";
	public string fichero ="";
	public string ficheroNivel="Nivel";
	public int niveles = 18;
	List<OptionsData> optionsdata = new List<OptionsData>();
	public string ficheroSetting ="/Setting.gd";
	public string ficheroRecord ="/Record.gd";
	List<RecordData> recorddata = new List<RecordData>();
	public bool hayerror = false;
	public string msgerror = "";


	void Awake(){
		PlayGamesPlatform.DebugLogEnabled = true;
		PlayGamesPlatform.Activate ();
		CargarGoals ();
		CargarNivel ();
		CargarSettings ();
		CargarRecord ();
		CargarNiveles.generalMaxNivel = niveles;
	}

	// Use this for initialization
	void Start () {
	// Comprueba si el usuario se habia iniciado en google play antes y si es asi se inicia automaticamente
		((PlayGamesPlatform)Social.Active).Authenticate ((bool success) => {}, true);



	
	}
	
	// Update is called once per frame
	void Update () {
	
	}
	void CargarGoals(){


		for (int i=1; i<=niveles; i++) {
			try
			{

				fichero = ficheroGoals + i.ToString ();
				fullZipPathName = Application.persistentDataPath + "/" + fichero + ".gd";
				if (!System.IO.File.Exists (fullZipPathName)) {
					TextAsset textAsset = Resources.Load (fichero, typeof(TextAsset)) as TextAsset;
					System.IO.File.WriteAllBytes (fullZipPathName, textAsset.bytes);

				}
			}catch (UnauthorizedAccessException e){
				hayerror = true;
				msgerror = "  Unauthorized Access to write files " + e.Message;
				
			}catch (Exception e){
				
				hayerror = true;
				msgerror = e.Message;
			}
		}

	}
	void CargarNivel(){
		for (int i=1; i<=niveles; i++) {
			try {
				fichero = ficheroNivel + i.ToString ();
				fullZipPathName = Application.persistentDataPath + "/" + fichero + ".gd";
				if (!System.IO.File.Exists (fullZipPathName)) {
					TextAsset textAsset = Resources.Load (fichero, typeof(TextAsset)) as TextAsset;
					System.IO.File.WriteAllBytes (fullZipPathName, textAsset.bytes);
				}
			}catch (UnauthorizedAccessException e){
				hayerror = true;
				msgerror = "  Unauthorized Access to write files " + e.Message;
				
			}catch (Exception e){
				
				hayerror = true;
				msgerror = e.Message;
			}
		}
	}
	void CargarSettings(){
		fichero = "Setting";
		fullZipPathName = Application.persistentDataPath + "/" + fichero + ".gd";
		try {
			if (!System.IO.File.Exists (fullZipPathName)) {
					TextAsset textAsset = Resources.Load (fichero, typeof(TextAsset)) as TextAsset;
					System.IO.File.WriteAllBytes (fullZipPathName, textAsset.bytes);
			}
			CargarVolumen ();
		}catch (UnauthorizedAccessException e){
			hayerror = true;
			msgerror = "  Unauthorized Access to write files " + e.Message;
			
		}catch (Exception e){
			
			hayerror = true;
			msgerror = e.Message;
		}

	}
	void CargarVolumen(){
		try {
			BinaryFormatter bf = new BinaryFormatter();
			FileStream file = File.Open (Application.persistentDataPath + ficheroSetting,FileMode.Open);
			optionsdata = (List<OptionsData>)bf.Deserialize(file);
			CargarNiveles.generalVolumenFx = optionsdata [0].volumeFx;
			CargarNiveles.generalVolumenMusic = optionsdata [0].volumeMusic;
			file.Close ();

		}catch (UnauthorizedAccessException e){
			hayerror = true;
			msgerror = "  Unauthorized Access to write files " + e.Message;

		}catch (Exception e){
			
			hayerror = true;
			msgerror = e.Message;
		}

	}

	void CargarRecord(){
		fullZipPathName = Application.persistentDataPath + ficheroRecord;
		try {

			if (!System.IO.File.Exists (fullZipPathName)) {
				recorddata.Add (new RecordData(1,0,"",System.DateTime.Now.ToString()));
				CargarNiveles.generalNivel = 1;
				SalvarRecord();

			}

		}catch (UnauthorizedAccessException e){
			hayerror = true;
			msgerror = "  Unauthorized Access to write files " + e.Message;
			
		}catch (Exception e){
			
			hayerror = true;
			msgerror = e.Message;
		}
		
		
	}
	void SalvarRecord(){
		try {

			BinaryFormatter bf = new BinaryFormatter();
			FileStream file = File.Create (Application.persistentDataPath + ficheroRecord);
			bf.Serialize(file, recorddata);
			file.Close();
		}catch (UnauthorizedAccessException e){
			hayerror = true;
			msgerror = "  Unauthorized Access to write files " + e.Message;
			
		}catch (Exception e){
			
			hayerror = true;
			msgerror = e.Message;
		}
		
	}
	void OnGUI() {
		if (hayerror) {
			GUI.Label (new Rect (0, 0, Screen.width, Screen.height),"Error. Aplication going be closed." + msgerror );
			Invoke("CerrarApp",4f);
		}
	}
	void CerrarApp(){
		Application.Quit ();
	}
		
	}
